package com.fractalite.hermes.teldar.parsers;

import java.io.IOException;
import java.text.ParseException;

import javax.xml.parsers.ParserConfigurationException;
import javax.xml.xpath.XPathExpressionException;

import org.apache.camel.Exchange;
import org.apache.camel.InvalidPayloadException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.xml.sax.SAXException;

import com.fractalite.hermes.teldar.tools.ObjectToXml;
import com.fractalite.models.commerce.Order;
import com.fractalite.models.commerce.OrderStatus;
import com.gekko_holding.webservice.v2_4.CancelBookingSegmentResponse;


public class BookingCancellationTeldResponse extends TeldarParsers {

	protected static Logger logger = LoggerFactory.getLogger(BookingCancellationTeldResponse.class);

	@Override
	public void process(Exchange exchange) throws InvalidPayloadException, ParserConfigurationException, SAXException,
			IOException, XPathExpressionException, ParseException {

		logger.info("Invoking TELDAR BookingCancellationResponse Processor.......");
		Order oldOrder = exchange.getProperty("TeldarOrder", Order.class);
		CancelBookingSegmentResponse cancelresp = exchange.getIn().getMandatoryBody(CancelBookingSegmentResponse.class);

		Order order = printHotelInfo(cancelresp, oldOrder);

		exchange.getIn().setBody(ObjectToXml.printXML(order));
		logger.info("End TELDAR BookingCancellationResponse Processor.......");

	}

	private Order printHotelInfo(CancelBookingSegmentResponse cancelresp, Order oldOrder)
			throws XPathExpressionException {

		if (cancelresp.getOperationStatus() != null && !cancelresp.getOperationStatus().isEmpty()
				&& cancelresp.getOperationStatus().toString().equals("SUCCESS")) {

			oldOrder.setStatus(OrderStatus.CANCELED);

		}

		return oldOrder;
	}

}
