package com.fractalite.hermes.teldar.parsers;

import java.io.IOException;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.List;

import javax.xml.parsers.ParserConfigurationException;
import javax.xml.xpath.XPathExpressionException;

import org.apache.camel.Exchange;
import org.apache.camel.InvalidPayloadException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.xml.sax.SAXException;

import com.fractalite.models.common.Address;
import com.fractalite.models.common.CodeNamePair;
import com.fractalite.models.common.Company;
import com.fractalite.models.common.Location;
import com.fractalite.models.common.PhoneNumberEntry;
import com.fractalite.models.travel.stay.Hotel;
import com.fractalite.models.travel.stay.Image;
import com.gekko_holding.webservice.v2_4.Description;
import com.gekko_holding.webservice.v2_4.Facility;
import com.gekko_holding.webservice.v2_4.GetHotelDetailsResponse;
import com.gekko_holding.webservice.v2_4.HotelBean;
import com.google.i18n.phonenumbers.NumberParseException;
import com.google.i18n.phonenumbers.PhoneNumberUtil;
import com.google.i18n.phonenumbers.Phonenumber.PhoneNumber;

public class ParseHoteldetailsResponse extends TeldarParsers {

	protected static Logger logger = LoggerFactory.getLogger(ParseHoteldetailsResponse.class);

	@Override
	public void process(Exchange exchange) throws InvalidPayloadException, ParserConfigurationException, SAXException,
			IOException, XPathExpressionException, ParseException {
		// TODO Auto-generated method stub
		logger.info("\n Invoking TELDAR ParseDetailHotel Processor....... " + exchange.getIn().getBody());
		GetHotelDetailsResponse resp = exchange.getIn().getMandatoryBody(GetHotelDetailsResponse.class);
		logger.info("\n Invoking TELDAR Pars=]DetailHotel Processor....... " + resp.getHotel().size());
		Hotel result = printHotelInfo(resp);
		logger.info("\n End TELDAR ParseDetailHotel Processor"+ com.fractalite.hermes.teldar.tools.ObjectToXml.printXML(result));
		exchange.getOut().setBody(result, Hotel.class);
		
	}

	/**
	 * @param respdetail
	 * @return
	 * @throws XPathExpressionException
	 */
	private Hotel printHotelInfo(GetHotelDetailsResponse respdetail) throws XPathExpressionException {

		Hotel hermesHotel = new Hotel();

		if (respdetail != null && respdetail.getHotel() != null && !respdetail.getHotel().isEmpty()) {

			for (HotelBean respBean : respdetail.getHotel()) {

				if (respBean.getHotelRating() != null) {
					HotelRatingg rating;
					if (respBean.getHotelRating().equals("UNKNOWN") || respBean.getHotelRating().equals("UNRATED")) {
						rating = HotelRatingg.valueOf(respBean.getHotelRating());
					} else {
						rating = HotelRatingg.valueOf("_" + respBean.getHotelRating());
					}

					if (rating != null) {
						hermesHotel.setRating(new CodeNamePair(String.valueOf(rating.value()), rating.value() + "ST"));
					}
				}

				if (respBean.getHotelCode() != null) {
					hermesHotel.setCode(respBean.getHotelCode());

				}

				if (respBean.getHotelName() != null) {
					hermesHotel.setName(respBean.getHotelName());
				}

				if (respBean.getHotelChain().getCode() != null) {
					hermesHotel.setChain(new Company(respBean.getHotelChain().getCode()));

				}
				if (respBean.getGeoLocalization() != null) {
					hermesHotel.setLatitude((float) respBean.getGeoLocalization().getLatitude());
					hermesHotel.setLongitude((float) respBean.getGeoLocalization().getLongitude());
				}

				if (respBean.getFax() != null) {
					hermesHotel.addPhoneNumber("fax", new PhoneNumber().setExtension(respBean.getFax()));
				}

				if (respBean.getGeoLocalization() != null) {
					hermesHotel.setDescription(String.valueOf(respBean.getDescriptions()));

				}

				if (respBean.getAddress() != null) {
					hermesHotel.setAddress(new Address("", "", new Location(String.valueOf(respBean.getCity())),
							new Location("", "")));

					com.fractalite.models.common.Address hermesAddress = new Address(respBean.getAddress(), "",
							new Location(respBean.getCity().getCode().substring(2, 5),
									respBean.getCity().getCode().substring(2, 5)),
							new Location(respBean.getCity().getCode().substring(0, 2),
									respBean.getCity().getCode().substring(0, 2)));
					hermesHotel.setAddress(hermesAddress);

				}
				// long ii = 12345678910L;
				if (respBean.getPhone() != null) {
					PhoneNumber phone;
					logger.info("phhhhhhhhh" + respBean.getPhone());
					try {
						phone = PhoneNumberUtil.getInstance().parse(respBean.getPhone(), "FR");
						hermesHotel.getPhoneNumbers().add(new PhoneNumberEntry("Phone", phone));
					} catch (NumberParseException e) {
						// TODO Auto-generated catch block

						logger.info("mesgggggg" + e.getMessage());

					}

				}

				else {

					logger.info("no numbrrr");
				}
				if (respBean.getEmail() != null) {
					hermesHotel.setEmail(respBean.getEmail());
				}

				if (respBean.getShortDescription() != null) {
					hermesHotel.setDescription(respBean.getShortDescription());
				}

				if (respBean.getThumbnailUrl() != null) {
					hermesHotel.setTaRatingUrl(respBean.getThumbnailUrl());
				}

				if (respBean.getDescriptions() != null && respBean.getDescriptions().getDescription() != null
						&& !respBean.getDescriptions().getDescription().isEmpty()) {

					Description description = new Description();

					List<String> descriptions = new ArrayList<String>();
					for (Description respdesc : respBean.getDescriptions().getDescription()) {
						if (respdesc.getType() != null && !respdesc.getType().isEmpty()) {
							descriptions.add(description.getType());
						}

						hermesHotel.setType(respdesc.getType());
					}

				}

				if (respBean.getFacilities() != null && respBean.getFacilities().getFacility() != null
						&& !respBean.getFacilities().getFacility().isEmpty()) {

					// list of all facilities content[e.g: Accès Internet] not code[e.g : SVGEKKO-1]

					List<String> facilities = new ArrayList<String>();
					for (Facility respFacility : respBean.getFacilities().getFacility()) {
						if (respFacility.getCode() != null && !respFacility.getCode().isEmpty()) {
							facilities.add(respFacility.getValue());
							String a = respFacility.getValue();
							logger.info("facilecode" + a);

							com.fractalite.hermes.teldar.parsers.Facility hermesFacility = com.fractalite.hermes.teldar.parsers.Facility
									.valueOf(respFacility.getCode().replace("-", "_"));

							logger.info("facecode" + respFacility.getCode());

							if (hermesFacility != null) {
								facilities.add(respFacility.getValue());

							}

						}
					}
					hermesHotel.setAmenities(facilities);
				}

				if (respBean.getImages() != null) {
					List<Image> hermesimages = new ArrayList<Image>();

					int id = 0;
					 logger.info("imgesssss"+respBean.getImages().getImage().size());
					for (int i = 0; i < respBean.getImages().getImage().size(); i++) {
						String ig = respBean.getImages().getImage().get(i).getValue().toString();
						 logger.info("imgesssss12"+ig);
						Image img = new Image();
						img.setUrl(ig);
						hermesimages.add(img);
					}

				     logger.info("immmmmages"+hermesimages.size()+" "+id);

					hermesHotel.setType(String.valueOf(respBean.getImages()));

					hermesHotel.setImages(hermesimages);

				}

			}

		}
		return hermesHotel;
	}

	

}
