package com.fractalite.hermes.teldar.services;

import java.text.SimpleDateFormat;

import javax.xml.datatype.DatatypeConfigurationException;

import org.apache.camel.Exchange;
import org.apache.camel.InvalidPayloadException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import com.fractalite.hermes.teldar.cfg.TeldarRouteBuilder;
import com.fractalite.hermes.teldar.tools.ObjectToXml;
import com.fractalite.models.commerce.Order;
import com.fractalite.models.travel.stay.HotelStay;
import com.fractalite.models.travel.stay.StayItem2;
import com.gekko_holding.webservice.v2_4.CustomerIdentification;
import com.gekko_holding.webservice.v2_4.GetPreBookingInfo;
import com.gekko_holding.webservice.v2_4.HotelCode;
import com.gekko_holding.webservice.v2_4.SearchCriteria;


public class PreBookingTeldarRequest extends TeldarServices{

	protected static Logger logger = LoggerFactory.getLogger(PreBookingTeldarRequest.class);

	@Override
	public void process(Exchange exchange) throws InvalidPayloadException, DatatypeConfigurationException {

		logger.info("Invoking TELDAR PreBookingTeldarRequest Processor.......");
		Order order = exchange.getIn().getMandatoryBody(Order.class);
		exchange.setProperty("hermesorder", order); 
		logger.info("Order is " + ObjectToXml.printXML(order));
		GetPreBookingInfo prebook = addBooking(order);
		logger.info("End TELDAR PreBookingTeldarRequest Processor....... \n" + ObjectToXml.printXML(prebook));
		exchange.getIn().setBody(prebook, GetPreBookingInfo.class);

	}

	public GetPreBookingInfo addBooking(Order order) throws DatatypeConfigurationException {

		GetPreBookingInfo bookinginfo = new GetPreBookingInfo();
		CustomerIdentification customeridentification = new CustomerIdentification();

		customeridentification.setClientId(TeldarRouteBuilder.clientId);
		customeridentification.setPassword(TeldarRouteBuilder.password);


		bookinginfo.setLanguage("EN");
		bookinginfo.setIdentification(customeridentification);
		SearchCriteria searchcriteria = new SearchCriteria(); 
		SimpleDateFormat formatter = new SimpleDateFormat("yyyy-mm-dd");

		HotelStay hotelstay = ((HotelStay) order.getTrip().getContent().get(0));
		HotelCode hotelcode = new HotelCode();
		hotelcode.setCode(hotelstay.getHotel().getCode());
		 searchcriteria.setHotelCode(hotelcode);
		 logger.info("codeeeee"+hotelcode);


		searchcriteria.setStartDate(hotelstay.getCheckin().toString());
		searchcriteria.setEndDate(hotelstay.getCheckout().toString());


		bookinginfo.setSearchCriteria(searchcriteria);

		searchcriteria.setOfferCode(order.getPricing().getItems(StayItem2.class).get(0).getProduct().getCode());
		logger.info("CodeCriteria" + order.getPricing().getItems(StayItem2.class).get(0).getProduct().getCode());

		return bookinginfo;
	}
}