package com.fractalite.hermes.teldar.services;

import java.text.ParseException;

import javax.xml.datatype.DatatypeConfigurationException;

import org.apache.camel.Exchange;
import org.apache.camel.InvalidPayloadException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.fractalite.hermes.teldar.cfg.TeldarRouteBuilder;
import com.fractalite.hermes.teldar.tools.ObjectToXml;
import com.fractalite.models.commerce.Order;
import com.fractalite.models.commerce.TermOfSale;
import com.fractalite.models.travel.stay.StayItem2;
import com.gekko_holding.webservice.v2_4.CustomerIdentification;


public class QuoteTeldarRequestCancellation extends TeldarServices {

	protected static Logger logger = LoggerFactory.getLogger(QuoteTeldarRequestCancellation.class);

	@Override
	public void process(Exchange exchange)
			throws InvalidPayloadException, DatatypeConfigurationException, ParseException {

		logger.info("Invoking TELDAR QuoteRequestCancellation Processor.......");
		Order order = exchange.getIn().getMandatoryBody(Order.class);
		exchange.setProperty("hermesquery", order);

		int exchangeCount = 0;
		for (StayItem2 lineItem : order.getPricing().getItems(StayItem2.class)) {

			Order orderLineItem = new Order(order.getCurrency());
			orderLineItem.getPricing().addItem(lineItem);
			orderLineItem.setTrip(order.getTrip());

			orderLineItem.getTrip().getTravellers().removeAll(orderLineItem.getTrip().getTravellers());
			orderLineItem.getTrip().getTravellers().addAll(lineItem.getRooms().get(0).getGuests());

			String description = exchange.getContext().getProperties().get(Integer.toString(++exchangeCount));

			TermOfSale termOfSale = new TermOfSale();
			termOfSale.setDescription(description);

			lineItem.getProduct().getTermsOfSales().add(termOfSale);

		}
		exchange.getIn().setBody(order);
		logger.debug(ObjectToXml.printXML(order));

		CustomerIdentification customeridentification = new CustomerIdentification();

		customeridentification.setClientId(TeldarRouteBuilder.clientId);
		customeridentification.setPassword(TeldarRouteBuilder.password);


	}
}